@@ -155,6 +155,11 @@ def validate(subparsers,epilog,project_drs):
                                        In this situation, cdb_query will discard ({0}) tuples that do not have variables for\n\
                                        ALL of the requested experiments'.format(','.join(project_drs.simulations_desc)))
 
+    parser.add_argument('--no_check_availability',
+                     default=False, action='store_true',
+                     help='When this option is activated, checks only that the time stamp is within \n\
+                           the requested years and months.')
+
     input_arguments(parser)
     output_arguments(parser)
     parser.add_argument('--in_diagnostic_headers_file',
@@ -210,6 +215,12 @@ def download(subparsers,epilog,project_drs):
     inc_group.add_argument('--day',
                                  default=None, type=int_list,
                                  help='Retrieve only these comma-separated calendar days.')
+    inc_group.add_argument('--previous',
+                                 default=False, action='store_true',
+                                 help='Retrieve data from specified year, month, day AND the time step just BEFORE this retrieved data.')
+    inc_group.add_argument('--next',
+                                 default=False, action='store_true',
+                                 help='Retrieve data from specified year, month, day AND the time step just AFTER this retrieved data.')
     #slicing_arguments(inc_group,project_drs)
     #exc_group = parser.add_argument_group('Exclusions')
     #excluded_slicing_arguments(exc_group,project_drs)
@@ -260,6 +271,12 @@ def download_raw(subparsers,epilog,project_drs):
     inc_group.add_argument('--day',
                                  default=None, type=int_list,
                                  help='Retrieve only these comma-separated calendar days.')
+    inc_group.add_argument('--previous',
+                                 default=False, action='store_true',
+                                 help='Retrieve data from specified year, month, day AND the time step just BEFORE this retrieved data.')
+    inc_group.add_argument('--next',
+                                 default=False, action='store_true',
+                                 help='Retrieve data from specified year, month, day AND the time step just AFTER this retrieved data.')
     #slicing_arguments(inc_group,project_drs)
     #exc_group = parser.add_argument_group('Exclusions')
     #excluded_slicing_arguments(exc_group,project_drs)
