@@ -3,6 +3,7 @@ import subprocess
 
 import urllib2, httplib
 from cookielib import CookieJar
+import ssl
 
 import copy
 
@@ -28,27 +29,30 @@ class HTTPSClientAuthHandler(urllib2.HTTPSHandler):
     def getConnection(self, host, timeout=300):
         return httplib.HTTPSConnection(host, key_file=self.key, cert_file=self.cert)
 
-#def check_file_availability(url_name):
-#    wget_call='wget --spider --ca-directory={0} --certificate={1} --private-key={1}'.format(os.environ['X509_CERT_DIR'],os.environ['X509_USER_PROXY']).split(' ')
-#    wget_call.append(url_name)
-#
-#    proc=subprocess.Popen(wget_call,stdout=subprocess.PIPE,stderr=subprocess.PIPE)
-#    (out, err) = proc.communicate()
-#
-#    status_string='HTTP request sent, awaiting response... '
-#    error_codes=[ int(line.replace(status_string,'').split(' ')[0]) for line in err.splitlines() if status_string in line]
-#    length_string='Length: '
-#    lengths=[ int(line.replace(length_string,'').split(' ')[0]) for line in err.splitlines() if length_string in line]
-#   
-#    if 200 in error_codes and max(lengths)>0:
-#        return True
-#    else:
-#        return False
+def check_file_availability_wget(url_name):
+    wget_call='wget --spider --ca-directory={0} --certificate={1} --private-key={1}'.format(os.environ['X509_CERT_DIR'],os.environ['X509_USER_PROXY']).split(' ')
+    wget_call.append(url_name)
+
+    proc=subprocess.Popen(wget_call,stdout=subprocess.PIPE,stderr=subprocess.PIPE)
+    (out, err) = proc.communicate()
+
+    status_string='HTTP request sent, awaiting response... '
+    error_codes=[ int(line.replace(status_string,'').split(' ')[0]) for line in err.splitlines() if status_string in line]
+    length_string='Length: '
+    lengths=[ int(line.replace(length_string,'').split(' ')[0]) for line in err.splitlines() if length_string in line]
+   
+    if 200 in error_codes and max(lengths)>0:
+        return True
+    else:
+        return False
 
 def check_file_availability(url_name):
+    #Some monkeypathcing to get rid of SSL certificate verification:
+    ssl._create_default_https_context = ssl._create_unverified_context
     cj = CookieJar()
+    opener = urllib2.build_opener(HTTPSClientAuthHandler(os.environ['X509_USER_PROXY'], os.environ['X509_USER_PROXY']),urllib2.HTTPCookieProcessor(cj))
+    urllib2.install_opener(opener)
     try: 
-        opener = urllib2.build_opener(HTTPSClientAuthHandler(os.environ['X509_USER_PROXY'], os.environ['X509_USER_PROXY']),urllib2.HTTPCookieProcessor(cj))
         response = opener.open(url_name)
 
         if response.msg=='OK' and response.headers.getheaders('Content-Length')[0]:
@@ -60,6 +64,8 @@ def check_file_availability(url_name):
 
 def download_secure(url_name,dest_name):
     if check_file_availability(url_name):
+        #Some monkeypathcing to get rid of SSL certificate verification:
+        ssl._create_default_https_context = ssl._create_unverified_context
         cj = CookieJar()
         opener = urllib2.build_opener(HTTPSClientAuthHandler(os.environ['X509_USER_PROXY'], os.environ['X509_USER_PROXY']),urllib2.HTTPCookieProcessor(cj))
         data = opener.open(url_name)
